<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_CustomerNotes
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Ahmed Goda <hello@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CustomerNotes\Block\Adminhtml\Customer\Edit;

use Magento\Backend\Block\Template\Context;
use Magento\Customer\Controller\RegistryConstants;
use Magento\Framework\Data\Collection\AbstractDb;
use Magento\Framework\Data\FormFactory;
use Magento\Framework\Model\ResourceModel\Db\Collection\AbstractCollection;
use Magento\Framework\Phrase;
use Magento\Framework\Registry;
use Magento\Ui\Component\Layout\Tabs\TabInterface;
use Magento\Backend\Block\Widget\Form\Generic;
use Pinpoint\CustomerNotes\Model\NoteFactory;

/**
 * Customer account form block
 */
class Tab extends Generic implements TabInterface
{
    /**
     * Template
     *
     * @var string
     */
    protected $_template = 'customer/view/notes.phtml';

    /**
     * Core registry
     *
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry;

    /** @var NoteFactory */
    protected NoteFactory $_notesFactory;

    /**
     * Class Constructor
     *
     * @param \Magento\Backend\Block\Template\Context   $context
     * @param \Magento\Framework\Registry               $registry
     * @param \Magento\Framework\Data\FormFactory       $formFactory
     * @param NoteFactory                               $notesFactory
     * @param array                                     $data
     */
    public function __construct(
        Context $context,
        Registry $registry,
        FormFactory $formFactory,
        NoteFactory $notesFactory,
        array $data = []
    ) {
        $this->_coreRegistry = $registry;
		$this->_notesFactory = $notesFactory;
        parent::__construct($context, $registry, $formFactory, $data);
    }

    /**
     * Get tab label
     * @return \Magento\Framework\Phrase
     */
    public function getTabLabel(): Phrase
    {
        return __('Customer Notes');
    }

    /**
     * Get tab title
     * @return \Magento\Framework\Phrase
     */
    public function getTabTitle(): Phrase
    {
        return __('Customer Notes');
    }

    /**
     * Tab class getter
     *
     * @return string
     */
    public function getTabClass(): string
    {
        return '';
    }

    /**
     * Return URL link to Tab content
     *
     * @return string
     */
    public function getTabUrl(): string
    {
        return '';
    }

    /**
     * Tab should be loaded through Ajax call
     *
     * @return bool
     */
    public function isAjaxLoaded(): bool
    {
        return false;
    }

    /**
     * Get can show tab
     * @return bool
     */
    public function canShowTab(): bool
    {
        if ($this->getCustomerId()) {
            return true;
        }
        return false;
    }

    /**
     * Tab is hidden
     *
     * @return boolean
     */
    public function isHidden(): bool
    {
        return false;
    }

    /**
     * Get Notes To Display In Tab Content
     */
    public function getNotesCollection()
    {
        return $this->_notesFactory->create()
            ->getCollection()
            ->addFieldToFilter(
                'customer_id', ['eq' => $this->getCustomerId()]
            )
            ->setOrder('created_at', 'asc');
    }

    /**
     * Get customer ID
     *
     * @return string|null
     */
    public function getCustomerId(): ?string
    {
        return $this->_coreRegistry->registry(RegistryConstants::CURRENT_CUSTOMER_ID);
    }

    /**
     * Return URL link to list all notes
     *
     * @return string
     */
    public function getListNotesUrl(): string
    {
        return $this->getUrl('customer_notes/note/index', ['_secure' => $this->getRequest()->isSecure()]);
    }

    /**
     * Return URL link to add note
     *
     * @return string
     */
    public function getAddNoteUrl(): string
    {
        return $this->getUrl('customer_notes/note/add', ['_secure' => $this->getRequest()->isSecure()]);
    }

    /**
     * Return URL link to delete note
     *
     * @return string
     */
    public function getDeleteNoteUrl(): string
    {
        return $this->getUrl('customer_notes/note/delete', ['_secure' => $this->getRequest()->isSecure()]);
    }
}
