<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_CustomerNotes
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Ahmed Goda <hello@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CustomerNotes\Controller\Adminhtml\Note;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\Controller\Result\Json;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\User\Model\User;
use Pinpoint\CustomerNotes\Model\Note;
use Magento\Backend\Model\Auth\Session;
use Psr\Log\LoggerInterface;

class Add extends Action
{
    /** @var JsonFactory */
    protected JsonFactory $resultJsonFactory;

    /** @var Note */
    protected Note $model;

    /** @var Session */
    protected Session $authSession;
    /**
     * @var \Psr\Log\LoggerInterface
     */
    private LoggerInterface $logger;

    /**
     * Class Constructor
     *
     * @param Context       $context
     * @param JsonFactory   $resultJsonFactory
     * @param Note          $model
     * @param Session       $authSession
     */
    public function __construct(
        Context $context,
        JsonFactory $resultJsonFactory,
        Note $model,
        Session $authSession,
        LoggerInterface $logger
    )
    {
        $this->resultJsonFactory = $resultJsonFactory;
        $this->model = $model;
        $this->authSession = $authSession;
        $this->logger = $logger;
        parent::__construct($context);
    }

    /**
     * Get is allowed
     * @return bool
     * {@inheritDoc}
     */
    protected function _isAllowed(): bool
    {
        return true;
    }

    /**
     * Get current user
     * @return \Magento\User\Model\User
     */
    private function getCurrentUser(): User
    {
        return $this->authSession->getUser();
    }

    /**
     * Execute add functionality
     * @return Json
     */
    public function execute()
    {
        /** @var \Magento\Framework\Controller\Result\Json $resultJson */
        $resultJson = $this->resultJsonFactory->create();
        try {
            $data = $this->getRequest()->getPostValue();
            /** @var array $response */
            $response = [];

            if (empty($data['customer_id'])) {
                $response['status'] = false;
                $response['message'] = __('Customer is Unkown!');
                return $resultJson->setData($response);
            }

            if (empty($data['customer_note'])) {
                $response['status'] = false;
                $response['message'] = __('Description shouldn\'t be blank!');
                return $resultJson->setData($response);
            }

            $model = $this->model->setData([
                'customer_id' => (int) $data['customer_id'],
                'author' => $this->getCurrentUser()->getFirstName() .' '. $this->getCurrentUser()->getLastName(),
                'description' => strip_tags($data['customer_note']),
            ]);
            $model->save();

            $response['status'] = true;
            $response['message'] = __('Successfully Added');

        } catch (\Exception $e) {
            $response['status'] = false;
            $response['message'] = __('An Error Occurred');
            $this->logger->critical($e);
        }
        return $resultJson->setData($response);
    }
}
