<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_CustomerNotes
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Ahmed Goda <hello@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CustomerNotes\Controller\Adminhtml\Note;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Action\Context;
use Magento\Framework\App\Request\Http;
use Magento\Framework\Controller\Result\Json;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\User\Model\User;
use Pinpoint\CustomerNotes\Model\NoteRepository;
use Magento\Backend\Model\Auth\Session;
use Psr\Log\LoggerInterface;

class Delete extends Action
{
    /** @var LoggerInterface $logger */
    protected LoggerInterface $logger;

    /** @var Session */
    protected Session $authSession;

    /** @var NoteRepository */
    protected NoteRepository $noteRepository;

    /** @var JsonFactory */
    protected JsonFactory $resultJsonFactory;

    /** @var Http */
    protected Http $request;

    /**
     * Class Constructor
     *
     * @param Context           $context
     * @param Http              $request
     * @param JsonFactory       $resultJsonFactory
     * @param NoteRepository    $noteRepository
     * @param Session           $authSession
     * @param LoggerInterface   $logger
     */
    public function __construct(
        Context         $context,
        Http            $request,
        JsonFactory     $resultJsonFactory,
        NoteRepository  $noteRepository,
        Session         $authSession,
        LoggerInterface $logger
    )
    {
        $this->request              = $request;
        $this->resultJsonFactory    = $resultJsonFactory;
        $this->noteRepository       = $noteRepository;
        $this->authSession          = $authSession;
        $this->logger               = $logger;
        parent::__construct($context);
    }

    /**
     * Get is allowed
     * @return bool
     * {@inheritDoc}
     */
    protected function _isAllowed(): bool
    {
        return true;
    }

    /**
     * Get current user
     */
    public function getCurrentUser(): ?User
    {
        return $this->authSession->getUser();
    }

    /**
     * Execute add functionality
     * @return Json
     */
    public function execute(): Json
    {
        try {
            $note_id = $this->request->getParam('note_id');

            $resultJson = $this->resultJsonFactory->create();

            $this->noteRepository->deleteNoteById((int) $note_id);

            /** @var array $response */
            $response = [];

            $response['status'] = true;
            $response['message'] = __('Deleted Successfully');

        } catch (\Exception $e) {
            $this->logger->critical($e);
            throw new CouldNotSaveException(
                __('The Note could not be deleted')
            );
        }

        return $resultJson->setData($response);
    }
}
