<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_CustomerNotes
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Ahmed Goda <hello@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CustomerNotes\Controller\Adminhtml\Note;

use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Request\Http;
use Magento\Framework\App\Action\Context;
use Magento\Framework\App\ResponseInterface;
use Magento\Framework\Controller\Result\Json;
use Magento\Framework\Controller\Result\JsonFactory;
use Magento\Backend\Model\Auth\Session;
use Magento\Framework\Controller\ResultInterface;
use Pinpoint\CustomerNotes\Block\Adminhtml\Customer\Edit\Tab;
use Pinpoint\CustomerNotes\Model\Note;
use Pinpoint\CustomerNotes\Model\NoteFactory;
use Psr\Log\LoggerInterface;

class Index extends Action
{
    /** @var LoggerInterface $logger */
    protected LoggerInterface $logger;

    /** @var JsonFactory */
    protected JsonFactory $resultJsonFactory;

    /** @var Note */
    protected Note $model;

    /** @var Session */
    protected Session $authSession;

    /** @var NoteFactory */
    protected NoteFactory $_notesFactory;
    /**
     * @var \Magento\Framework\App\Request\Http
     */
    private Http $request;

    /**
     * Class Constructor
     * @param Context $context
     * @param \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
     * @param Note $model
     * @param NoteFactory $notesFactory
     * @param LoggerInterface $logger
     * @param Http $request
     * @param \Magento\Backend\Model\Auth\Session $authSession
     */
    public function __construct(
        Context $context,
        JsonFactory $resultJsonFactory,
        Note $model,
        NoteFactory $notesFactory,
        LoggerInterface $logger,
        Http $request,
        Session $authSession
    )
    {
        $this->logger               = $logger;
        $this->resultJsonFactory    = $resultJsonFactory;
        $this->model                = $model;
		$this->_notesFactory        = $notesFactory;
        $this->authSession          = $authSession;
        $this->request              = $request;
        parent::__construct($context);
    }

    /**
     * Get is allowed
     *
     * @return bool
     * {@inheritDoc}
     */
    protected function _isAllowed(): bool
    {
        return true;
    }

    /**
     * Execute index functionality
     * @return Json|ResultInterface|ResponseInterface
     * {@inheritDoc}
     */
    public function execute()
    {
        /** @var \Magento\Framework\Controller\Result\Json $resultJson */
        $resultJson = $this->resultJsonFactory->create();

        try {

            $customerId = $this->request->getParam('customer_id');

            $notes = $this->_notesFactory->create()
                ->getCollection()
                ->addFieldToFilter(
                    'customer_id', ['eq' => $customerId]
                )
                ->setOrder('created_at', 'asc');

            /** @var \Magento\Framework\View\Layout $layout */
            $layout = $this->_view->getLayout();

            /** @var \Pinpoint\CustomerNotes\Block\Adminhtml\Customer\Note $block */
            $block = $layout->createBlock(Tab::class)
                ->setTemplate('Pinpoint_CustomerNotes::customer/view/index.phtml')
                ->assign([
                    'notes' => $notes
                ]);

            /** @var array $response */
            $response = [];

            $response['status'] = true;
            $response['content'] = $block->toHtml();

        } catch (\Exception $e) {
            $response['status'] = false;
            $response['message'] = __($e->getMessage());

            $this->logger->critical($e);
        }

        return $resultJson->setData($response);
    }
}
