<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_CustomerNotes
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Ahmed Goda <hello@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CustomerNotes\Model;

use Magento\Framework\Model\AbstractExtensibleModel;
use Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface;
use Pinpoint\CustomerNotes\Model\ResourceModel\Note as NoteResource;

/**
 * Class Note
 */
class Note extends AbstractExtensibleModel implements CustomerNoteInterface
{
    /**
     * Constructor
     * {@inheritdoc}
     */
    protected function _construct()
    {
        $this->_init(NoteResource::class);
    }

    /**
     * Get ID
     * @return int|null
     */
    public function getId(): ?int
    {
        return $this->getData(CustomerNoteInterface::ID);
    }

    /**
     * Get author
     * @return string
     */
    public function getAuthor(): string
    {
        return $this->getData(CustomerNoteInterface::AUTHOR);
    }

    /**
     * Get customer ID
     * @return int
     */
    public function getCustomerId(): int
    {
        return $this->getData(CustomerNoteInterface::CUSTOMER_ID);
    }

    /**
     * Get description
     * @return string
     */
    public function getDescription(): string
    {
        return $this->getData(CustomerNoteInterface::DESCRIPTION);
    }

    /**
     * Get created at
     * @return mixed
     */
    public function getCreatedAt()
    {
        return $this->getData(CustomerNoteInterface::CREATED_AT);
    }

    /**
     * Get updated at
     * @return mixed
     */
    public function getUpdatedAt()
    {
        return $this->getData(CustomerNoteInterface::UPDATED_AT);
    }

    /**
     * Set author
     * @param string $author
     * @return \Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface
     */
    public function setAuthor(string $author): CustomerNoteInterface
    {
        return $this->setData(CustomerNoteInterface::AUTHOR, $author);
    }

    /**
     * Set customer ID
     * @param int $customerId
     * @return \Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface
     */
    public function setCustomerId(int $customerId): CustomerNoteInterface
    {
        return $this->setData(CustomerNoteInterface::CUSTOMER_ID, $customerId);
    }

    /**
     * Srt description
     * @param string $description
     * @return \Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface
     */
    public function setDescription(string $description): CustomerNoteInterface
    {
        return $this->setData(CustomerNoteInterface::DESCRIPTION, $description);
    }

    /**
     * Set created at
     * @param string $createdAt
     * @return \Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface
     */
    public function setCreatedAt(string $createdAt): CustomerNoteInterface
    {
        return $this->setData(CustomerNoteInterface::CREATED_AT, $createdAt);
    }

    /**
     * Set updated at
     * @param string $updatedAt
     * @return \Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface
     */
    public function setUpdatedAt(string $updatedAt): CustomerNoteInterface
    {
        return $this->setData(CustomerNoteInterface::UPDATED_AT, $updatedAt);
    }
}
