<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_CustomerNotes
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Ahmed Goda <hello@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CustomerNotes\Model;

use Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface;
use Pinpoint\CustomerNotes\Api\NoteRepositoryInterface;
use Pinpoint\CustomerNotes\Model\{ResourceModel\Note\CollectionFactory, ResourceModel\Note};

/**
 * Class NoteRepository
 */
class NoteRepository implements NoteRepositoryInterface
{
    /** @var CollectionFactory */
    private CollectionFactory $collectionFactory;

    /** @var NoteFactory */
    private NoteFactory $noteFactory;

    /** @var Note */
    private Note $model;

    /**
     * Class constructor
     *
     * @param CollectionFactory     $collectionFactory
     * @param NoteFactory           $noteFactory
     * @param Note                  $model
     * @return void
     */
    public function __construct(
        CollectionFactory $collectionFactory,
        NoteFactory $noteFactory,
        Note $model
    )
    {
        $this->collectionFactory = $collectionFactory;
        $this->noteFactory       = $noteFactory;
        $this->model             = $model;
    }

    /**
     * Get List Collection Of Notes
     *
     * @return \Magento\Framework\DataObject[]
     */
    public function getList()
    {
        return $this->collectionFactory->create()->getItems();
    }

    /**
     * Get Note Resource By ID
     *
     * @param int $noteId
     * @return \Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface
     */
    public function getNoteById(int $noteId): CustomerNoteInterface
    {
        return $this->noteFactory->create()->load($noteId);
    }

    /**
     * Store Note Resource into Database
     * @param \Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface $note
     * @return \Pinpoint\CustomerNotes\Api\Data\CustomerNoteInterface
     * @throws \Magento\Framework\Exception\AlreadyExistsException
     */
    public function saveNote(CustomerNoteInterface $note): CustomerNoteInterface
    {
        if ($note->getId() == null) {
            $this->model->save($note);
            return $note;
        } else {
            $note = $this->noteFactory->create()->load($note->getId());
            foreach ($note->getData() as $key => $value) {
                $note->setData($key, $value);
            }
            $this->model->save($note);
            return $note;
        }
    }

    /**
     * Destroy Note By ID From Database
     * @param int $noteId
     * @return void
     * @throws \Exception
     */
    public function deleteNoteById(int $noteId)
    {
        $note = $this->noteFactory->create()->load($noteId);
        $note->delete();
    }
}
