<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_CustomerNotes
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Ahmed Goda <hello@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CustomerNotes\Setup;

use Magento\Framework\Setup\{ModuleContextInterface, InstallSchemaInterface, SchemaSetupInterface};
use Magento\Framework\Db\Ddl\Table;

/**
 * Class InstallSchema
 */
class InstallSchema implements InstallSchemaInterface
{

    /**
     * To Create Module Table By Updating Exist Schema
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     * @return void
     * @throws \Zend_Db_Exception
     */
    public function install(SchemaSetupInterface $setup, ModuleContextInterface $context): void
    {
        $installer = $setup;

        $installer->startSetup();

        $table = $installer->getConnection()
            ->newTable($installer->getTable($installer->getTable('customer_notes'))
                )->addColumn(
                    'note_id',
                    Table::TYPE_INTEGER,
                    null,
                    [
                        'identity' => true,
                        'unsigned' => true,
                        'nullable' => false,
                        'primary' => true
                    ],
                    'Note ID'
                )->addColumn(
                    'customer_id',
                    Table::TYPE_INTEGER,
                    null,
                    ['nullable' => false],
                    'Customer ID'
                )->addColumn(
                    'author',
                    Table::TYPE_TEXT,
                    255,
                    ['nullable' => false],
                    'Author'
                )->addColumn(
                    'description',
                    Table::TYPE_TEXT,
                    '2M',
                    ['nullable' => false],
                    'Description'
                )->addColumn(
                    'created_at',
                    Table::TYPE_TIMESTAMP,
                    null,
                    [
                        'nullable' => false,
                        'default' => Table::TIMESTAMP_INIT
                    ],
                    'Creation Time'
                )->addColumn(
                    'updated_at',
                    Table::TYPE_TIMESTAMP,
                    null,
                    [
                        'nullable' => false,
                        'default' => Table::TIMESTAMP_INIT
                    ],
                    'Update Time'
                )->addIndex(
                    $installer->getIdxName($installer->getTable('customer_notes'), ['note_id']),
                    ['note_id']
                )->setComment(
                    'Admin Customer Notes Table'
                );
        $installer->getConnection()->createTable($table);

        $installer->endSetup();
    }
}
